@@ -1,6 +1,6 @@
 package Ubic::Credentials::OS::POSIX;
 {
-  $Ubic::Credentials::OS::POSIX::VERSION = '1.57';
+  $Ubic::Credentials::OS::POSIX::VERSION = '1.58';
 }
 
 use strict;
@@ -228,8 +228,8 @@ sub eq {
     if (
         $self->effective_user_id == $other->effective_user_id
         and $self->real_user_id == $other->real_user_id
-        and $self->_groups_equal($self->effective_group_id, $other->effective_group_id)
-        and $self->_groups_equal($self->real_group_id, $other->real_group_id)
+        and $self->_groups_equal(join(" ", $self->effective_group_id), join(" ", $other->effective_group_id))
+        and $self->_groups_equal(join(" ", $self->real_group_id), join(" ", $other->real_group_id))
     ) {
         return 1;
     }
@@ -282,7 +282,7 @@ Ubic::Credentials::OS::POSIX - POSIX-specific credentials implementation
 
 =head1 VERSION
 
-version 1.57
+version 1.58
 
 =head1 METHODS
 
@@ -326,7 +326,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2015 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
