@@ -1,6 +1,6 @@
 package Ubic::Ping::Service;
 {
-  $Ubic::Ping::Service::VERSION = '1.57';
+  $Ubic::Ping::Service::VERSION = '1.58';
 }
 
 # ABSTRACT: ubic.ping service
@@ -47,7 +47,7 @@ sub new {
                 return 'not running';
             }
             my $ua = Ubic::UA->new(timeout => 1);
-            my $response = $ua->get("http://localhost:$port/ping");
+            my $response = $ua->get("http://127.0.0.1:$port/ping");
             if ($response->{error}) {
                 return result('broken', $response->{error});
             }
@@ -76,7 +76,7 @@ Ubic::Ping::Service - ubic.ping service
 
 =head1 VERSION
 
-version 1.57
+version 1.58
 
 =head1 INTERFACE SUPPORT
 
@@ -98,7 +98,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2015 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
