@@ -1,6 +1,6 @@
 package Ubic::Service::SimpleDaemon;
 {
-  $Ubic::Service::SimpleDaemon::VERSION = '1.57';
+  $Ubic::Service::SimpleDaemon::VERSION = '1.58';
 }
 
 use strict;
@@ -32,6 +32,23 @@ sub _pid_dir {
     return $PID_DIR;
 }
 
+sub _send_signal {
+    my ($self, $signal) = @_;
+
+    my $daemon = check_daemon($self->pidfile);
+    unless ($daemon) {
+        return result('not running');
+    }
+
+    my $pid = $daemon->pid;
+    kill $signal => $pid;
+
+    my $guardian_pid = $daemon->guardian_pid;
+    kill HUP => $guardian_pid;
+
+    return result('reloaded', "sent $self->{reload_signal} to $pid, sent HUP to $guardian_pid");
+}
+
 sub new {
     my $class = shift;
     my $params = validate(@_, {
@@ -48,6 +65,7 @@ sub new {
         env => { type => HASHREF, optional => 1 },
         reload_signal => { type => SCALAR, optional => 1 },
         term_timeout => { type => SCALAR, optional => 1, regex => qr/^\d+$/ },
+        stop_timeout => { type => SCALAR, optional => 1, regex => qr/^\d+$/ },
         ulimit => { type => HASHREF, optional => 1 },
         auto_start => { type => BOOLEAN, default => 0 },
     });
@@ -122,7 +140,9 @@ sub group {
 
 sub stop_impl {
     my ($self) = @_;
-    stop_daemon($self->pidfile);
+    my $options = {};
+    $options->{timeout} = $self->{stop_timeout} if $self->{stop_timeout};
+    stop_daemon($self->pidfile,$options);
 }
 
 sub status_impl {
@@ -140,18 +160,7 @@ sub reload {
     unless (defined $self->{reload_signal}) {
         return result('unknown', 'not implemented');
     }
-    my $daemon = check_daemon($self->pidfile);
-    unless ($daemon) {
-        return result('not running');
-    }
-
-    my $pid = $daemon->pid;
-    kill $self->{reload_signal} => $pid;
-
-    my $guardian_pid = $daemon->guardian_pid;
-    kill HUP => $guardian_pid;
-
-    return result('reloaded', "sent $self->{reload_signal} to $pid, sent HUP to $guardian_pid");
+    return $self->_send_signal($self->{reload_signal});
 }
 
 sub auto_start {
@@ -160,6 +169,26 @@ sub auto_start {
 }
 
 
+our %SIGNALS = (
+    sigusr1 => 'SIGUSR1',
+    sigusr2 => 'SIGUSR2',
+);
+
+sub custom_commands {
+    my ($self) = @_;
+    return keys %SIGNALS;
+}
+
+sub do_custom_command {
+    my ($self, $command) = @_;
+    unless (defined $SIGNALS{$command}) {
+        return result('unknown', 'not implemented');
+    }
+
+    return $self->_send_signal($SIGNALS{$command});
+}
+
+
 1;
 
 __END__
@@ -172,7 +201,7 @@ Ubic::Service::SimpleDaemon - service module for daemonizing any binary
 
 =head1 VERSION
 
-version 1.57
+version 1.58
 
 =head1 SYNOPSIS
 
@@ -269,6 +298,12 @@ Zero value means that guardian will send I<SIGKILL> to the daemon immediately.
 
 Default is 10 seconds.
 
+=item I<stop_timeout>
+
+Number of seconds to wait before raising exception that daemon can't be stopped.
+
+This should always be greater than I<term_timeout>, and defaults to 30 seconds (via L<Ubic::Daemon>'s defaults.)
+
 =item I<reload_signal>
 
 Send given signal to the daemon on C<reload> command.
@@ -303,6 +338,11 @@ Get pid filename. It will be concatenated from simple-daemon pid dir and service
 
 =back
 
+=head1 CUSTOM COMMANDS
+
+All services using this class support two custom commands: I<sigusr1> and I<sigusr2>.
+So, C<ubic sigusr1 your.service.name> will send I<SIGUSR1> to your daemon (and also send I<SIGHUP> to ubic-guardian, which can result in reopening log files.)
+
 =head1 SEE ALSO
 
 L<Ubic::Daemon> - module for daemonizing any binary.
@@ -313,7 +353,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2015 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
